@@ -6,7 +6,7 @@ use 5.008001;
 use Carp ();
 
 # ABSTRACT: Write Perl extensions using Wasm
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 
 sub import
@@ -22,6 +22,7 @@ sub import
   }
 
   my $api;
+  my $exporter;
   my @module;
   my $package = $caller;
 
@@ -75,6 +76,10 @@ sub import
         @module = (file => shift @maybe);
       }
     }
+    elsif($key eq '-exporter')
+    {
+      $exporter = shift;
+    }
     elsif($key eq '-package')
     {
       $package = shift;
@@ -98,6 +103,8 @@ sub import
   my @me = $module->exports;
   my @ie = $instance->exports;
 
+  my @function_names;
+
   for my $i (0..$#ie)
   {
     my $exporttype = $me[$i];
@@ -108,6 +115,22 @@ sub import
     {
       my $func = $extern->as_func;
       $func->attach($package, $name);
+      push @function_names, $name;
+    }
+  }
+
+  if($exporter)
+  {
+    require Exporter;
+    no strict 'refs';
+    push @{ "${package}::ISA"       }, 'Exporter';
+    if($exporter eq 'all')
+    {
+      push @{ "${package}::EXPORT" }, @function_names;
+    }
+    else
+    {
+      push @{ "${package}::EXPORT_OK" }, @function_names;
     }
   }
 }
@@ -126,7 +149,7 @@ Wasm - Write Perl extensions using Wasm
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -179,11 +202,13 @@ The C<Wasm> Perl dist provides tools for writing Perl bindings using WebAssembly
 
 As of this writing, since the API is subject to change, this must be provided and set to C<0>.
 
-=head2 -wat
+=head2 -exporter
 
- use Wasm -api => 0, -wat => $wat;
+ use Wasm -api => 0, -exporter => 'all';
+ use Wasm -api => 0, -exporter => 'ok';
 
-String containing WebAssembly Text (WAT).  Helpful for inline WebAssembly inside your Perl source file.
+Configure the caller as an L<Exporter>, with all the functions in the WebAssembly either C<@EXPORT> (C<all>)
+or C<@EXPORT_OK> C(<ok>).
 
 =head2 -file
 
@@ -191,6 +216,12 @@ String containing WebAssembly Text (WAT).  Helpful for inline WebAssembly inside
 
 Path to a WebAssembly file in either WebAssembly Text (.wat) or WebAssembly binary (.wasm) format.
 
+=head2 -package
+
+ use Wasm -api => 0, -package => $package;
+
+Install subroutines in to C<$package> namespace instead of the calling namespace.
+
 =head2 -self
 
  use Wasm -api => 0, -self;
@@ -201,11 +232,11 @@ the Perl source this is called from.
 For example if you are calling this from C<lib/Foo/Bar.pm>, it will look for C<lib/Foo/Bar.wat> and
 C<lib/Foo/Bar.wasm>.  If both exist, then it will use the newer of the two.
 
-=head2 -package
+=head2 -wat
 
- use Wasm -api => 0, -package => $package;
+ use Wasm -api => 0, -wat => $wat;
 
-Install subroutines in to C<$package> namespace instead of the calling namespace.
+String containing WebAssembly Text (WAT).  Helpful for inline WebAssembly inside your Perl source file.
 
 =head1 SEE ALSO
 
