@@ -2,11 +2,12 @@ package Wasm::Wasmtime::FuncType;
 
 use strict;
 use warnings;
+use Ref::Util qw( is_ref );
 use Wasm::Wasmtime::FFI;
 use Wasm::Wasmtime::ValType;
 
 # ABSTRACT: Wasmtime function type class
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 
 $ffi_prefix = 'wasm_functype_';
@@ -17,7 +18,7 @@ $ffi->attach( new => ['wasm_valtype_vec_t*', 'wasm_valtype_vec_t*'] => 'wasm_fun
   my $xsub = shift;
   my $class = shift;
   my($ptr, $owner);
-  if(ref $_[0])
+  if(is_ref $_[0])
   {
     # try not to think too much about all of the maps here
     my($params, $results) = map { my $rec = Wasm::Wasmtime::ValTypeVec->new; $rec->set($_) }
@@ -46,6 +47,15 @@ $ffi->attach( results => ['wasm_functype_t'] => 'wasm_valtype_vec_t*' => sub {
   $xsub->($self->{ptr})->to_list;
 });
 
+
+# actually returns a wasm_externtype_t, but recursion
+$ffi->attach( as_externtype => ['wasm_functype_t'] => 'opaque' => sub {
+  my($xsub, $self) = @_;
+  require Wasm::Wasmtime::ExternType;
+  my $ptr = $xsub->($self->{ptr});
+  Wasm::Wasmtime::ExternType->new($ptr, $self->{owner} || $self);
+});
+
 $ffi->attach( [ delete => "DESTROY" ] => ['wasm_functype_t'] => sub {
   my($xsub, $self) = @_;
   if(defined $self->{ptr} && !defined $self->{owner})
@@ -68,7 +78,7 @@ Wasm::Wasmtime::FuncType - Wasmtime function type class
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -112,6 +122,12 @@ Returns a list of the parameter types for the function type, as L<Wasm::Wasmtime
 
 Returns a list of the result types for the function type, as L<Wasm::Wasmtime::ValType> objects.
 
+=head2 as_externtype
+
+ my $externtype = $func->as_externtype
+
+Returns the L<Wasm::Wasmtime::ExternType> for this function type.
+
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
