@@ -2,12 +2,13 @@ package Wasm::Wasmtime::Memory;
 
 use strict;
 use warnings;
+use Ref::Util qw( is_ref );
 use Wasm::Wasmtime::FFI;
 use Wasm::Wasmtime::Store;
 use Wasm::Wasmtime::MemoryType;
 
 # ABSTRACT: Wasmtime memory class
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 
 $ffi_prefix = 'wasm_memory_';
@@ -19,7 +20,7 @@ $ffi->attach( new => ['wasm_store_t', 'wasm_memorytype_t'] => 'wasm_memory_t' =>
   my $class = shift;
   my $ptr;
   my $owner;
-  if(ref $_[0])
+  if(is_ref $_[0])
   {
     my($store, $memorytype) = @_;
     $ptr = $xsub->($store->{ptr}, $memorytype->{ptr});
@@ -87,7 +88,7 @@ Wasm::Wasmtime::Memory - Wasmtime memory class
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
