@@ -2,10 +2,11 @@ package Wasm::Wasmtime::MemoryType;
 
 use strict;
 use warnings;
+use Ref::Util qw( is_ref );
 use Wasm::Wasmtime::FFI;
 
 # ABSTRACT: Wasmtime memory type class
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 
 $ffi_prefix = 'wasm_memorytype_';
@@ -17,7 +18,7 @@ $ffi->attach( new => ['uint32[2]'] => 'wasm_memorytype_t' => sub {
   my $class = shift;
   my $ptr;
   my $owner;
-  if(ref $_[0])
+  if(is_ref $_[0])
   {
     $ptr = $xsub->(shift);
   }
@@ -38,6 +39,15 @@ $ffi->attach( limits => ['wasm_memorytype_t'] => 'uint32[2]' => sub {
   $limits;
 });
 
+
+# actually returns a wasm_externtype_t, but recursion
+$ffi->attach( as_externtype => ['wasm_memorytype_t'] => 'opaque' => sub {
+  my($xsub, $self) = @_;
+  require Wasm::Wasmtime::ExternType;
+  my $ptr = $xsub->($self->{ptr});
+  Wasm::Wasmtime::ExternType->new($ptr, $self->{owner} || $self);
+});
+
 $ffi->attach( [ delete => "DESTROY" ] => ['wasm_memorytype_t'] => sub {
   my($xsub, $self) = @_;
   if(defined $self->{ptr} && !defined $self->{owner})
@@ -60,7 +70,7 @@ Wasm::Wasmtime::MemoryType - Wasmtime memory type class
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -94,6 +104,12 @@ Creates a new memory type object.
 
 Returns the minimum and maximum number of pages as an array reference.
 
+=head2 as_externtype
+
+ my $externtype = $memory->as_externtype
+
+Returns the L<Wasm::Wasmtime::ExternType> for this memory type.
+
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
